# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['swagger_codegen',
 'swagger_codegen.api',
 'swagger_codegen.api.adapter',
 'swagger_codegen.cli',
 'swagger_codegen.parsing',
 'swagger_codegen.render',
 'swagger_codegen.render.post_processors',
 'swagger_codegen.render.renderers']

package_data = \
{'': ['*'], 'swagger_codegen': ['templates/package_renderer/*']}

install_requires = \
['click>=7.1.1,<8.0.0',
 'inflection>=0.4.0,<0.5.0',
 'jinja2>=2.11.1,<3.0.0',
 'multidict>=4.7.5,<5.0.0',
 'pydantic>=1.4,<2.0',
 'rich>=0.8.11,<0.9.0',
 'schemathesis==1.1.0',
 'toml>=0.10.0,<0.11.0',
 'typer>=0.1.1,<0.2.0']

extras_require = \
{'all': ['aiohttp', 'requests', 'black'],
 'async': ['aiohttp'],
 'black': ['black'],
 'sync': ['requests']}

entry_points = \
{'console_scripts': ['swagger_codegen = swagger_codegen.cli.main:app']}

setup_kwargs = {
    'name': 'swagger-codegen',
    'version': '0.1.21',
    'description': 'Generate API clients by parsing Swagger definitions',
    'long_description': '## Swagger codegen for Python\n\n### Installation\n\n```bash\npip install swagger-codegen\n```\n\n### Usage example\n\n```\n# Generate Petstore Api client using \'petstore\' package name.\nswagger_codegen generate http://petstore.swagger.io:8080/api/v3/openapi.json petstore\n\npython\n\nPython 3.8.1 (default, Jan 23 2020, 13:58:52) \n[Clang 11.0.0 (clang-1100.0.33.16)] on darwin\nType "help", "copyright", "credits" or "license" for more information.\n\n>>> from petstore import new_client, Configuration\n>>> from swagger_codegen.api.adapter.requests import RequestsAdapter\n>>> from petstore.apis.user.createUser import User\n>>> client = new_client(RequestsAdapter(), Configuration(host="http://petstore.swagger.io:8080"))\n>>> print(client.user.createUser(User(id=1, username="Swagger-Codegen")))\nid=1 username=\'Swagger-Codegen\' firstName=None lastName=None email=None password=None phone=None userStatus=0\n```\n\nYou can see [example source code](https://github.com/asyncee/swagger_codegen/tree/master/example)\nfor [PetStore](http://petstore.swagger.io:8080/) Api in example directory of a project.\n\nYou can test example client with following command:\n\n```bash\n# Run from project directory.\npython -m example.petstore_example \n```\n\n### Code generators (also known as renderers)\n\nThere are two code generator strategies in project:\n\n1. Render client as usual python package via `PackageRenderer`\n2. Render client as installable python package via `InstallablePackageRenderer`\n\nYou can choose what renderer to use by specifying `renderer` key in `.swagger-codegen.toml`\nfile. Please see `.swagger-codegen.toml.example` for allowed values.\n\n### Known issues\n\n- Content of generated files differs run-to-run because each time functions or data\ndata transfer objects ordered differently. Functionally clients stay the same, but\neach time the code is generated there are large diff generated by git.\n\n### Work in progress\n\nThough library gives nice results for generated API, it is still in development.\nSome tests are missing. API is a subject to change until stable release.\n\nAnyway backward compatibility will be kept as most as possible.\n\nThe code is not optimized yet and mostly dirty because the project was born\nas a holiday prototype.\n\nAlso `example` directory may be out of sync with actual generated code.\n\n### Contributors\n\n- livestalker\n- coderfromhere\n',
    'author': 'asyncee',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/asyncee/swagger_codegen',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
